@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -33,11 +33,14 @@ public:
     DeintSettingsW();
     ~DeintSettingsW();
 
+    void setSoftwareDeintEnabledDisabled();
+
     void writeSettings();
 private slots:
     void softwareMethods(bool doubler);
     void setSoftwareMethodsToolTip(int idx);
 private:
     QCheckBox *autoDeintB, *doublerB, *autoParityB;
+    QCheckBox *m_vkYadifSpatialCheck = nullptr;
     QComboBox *softwareMethodsCB, *parityCB;
 };
