@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -67,7 +67,8 @@ private:
     QCommonStyle commonStyle;
     int pixels;
     Qt::KeyboardModifiers m_pressedKeyModifiers = Qt::NoModifier;
-    bool canPopup, is_floating, isBreeze, canHideIDWCursor, doubleClicked;
+    bool canPopup, is_floating, canHideIDWCursor, doubleClicked;
+    QMargins m_contentMarginsBackup;
     double touchZoom;
     bool m_workaround = false;
 private slots:
