@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -19,20 +19,31 @@
 #include <VideoThr.hpp>
 
 #include <VideoAdjustmentW.hpp>
+#include <ScreenSaver.hpp>
 #include <PlayClass.hpp>
 #include <Main.hpp>
 
+#include <GPUInstance.hpp>
+#include <HWDecContext.hpp>
 #include <VideoWriter.hpp>
 #include <QMPlay2OSD.hpp>
-#include <VideoFrame.hpp>
+#include <Frame.hpp>
 #include <Settings.hpp>
 #include <Decoder.hpp>
 #include <LibASS.hpp>
-
-#include <ScreenSaver.hpp>
 #include <ImgScaler.hpp>
 #include <Functions.hpp>
+
+#ifdef USE_OPENGL
+#   include <opengl/OpenGLHWInterop.hpp>
+#endif
+#ifdef USE_VULKAN
+#   include <vulkan/VulkanHWInterop.hpp>
+#   include <vulkan/VulkanYadifDeint.hpp>
+#endif
+
 using Functions::gettime;
+using namespace std;
 
 #include <QDebug>
 #include <QImage>
@@ -40,15 +51,25 @@ using Functions::gettime;
 
 #include <cmath>
 
-VideoThr::VideoThr(PlayClass &playC, VideoWriter *hwAccelWriter, const QStringList &pluginsName) :
-    AVThread(playC, "video:", hwAccelWriter, pluginsName),
+VideoThr::VideoThr(PlayClass &playC, const QStringList &pluginsName) :
+    AVThread(playC),
+    syncVtoA(QMPlay2Core.getSettings().getBool("SyncVtoA")),
     doScreenshot(false),
     deleteOSD(false), deleteFrame(false), gotFrameOrError(false), decoderError(false),
     W(0), H(0), seq(0),
     sDec(nullptr),
-    hwAccelWriter(hwAccelWriter),
     subtitles(nullptr)
 {
+    if (QMPlay2Core.renderer() != QMPlay2CoreClass::Renderer::Legacy)
+    {
+        writer = QMPlay2Core.gpuInstance()->createOrGetVideoOutput();
+        videoWriter()->open();
+    }
+    else
+    {
+        writer = Writer::create("video:", pluginsName);
+    }
+
     maybeStartThread();
 }
 VideoThr::~VideoThr()
@@ -61,8 +82,30 @@ VideoThr::~VideoThr()
     delete sDec;
 }
 
+void VideoThr::setDec(Decoder *dec)
+{
+    AVThread::setDec(dec);
+    if (!dec->hasHWDecContext() && videoWriter()->hwDecContext())
+        videoWriter()->setHWDecContext(nullptr);
+    decoderError = false;
+}
+
+shared_ptr<HWDecContext> VideoThr::getHWDecContext() const
+{
+    return videoWriter()->hwDecContext();
+}
+
+bool VideoThr::videoWriterSet()
+{
+    if (QMPlay2Core.renderer() == QMPlay2CoreClass::Renderer::Legacy)
+        return false; // Force restart to use possible new order of video outputs
+    return writer->set();
+}
+
 void VideoThr::stop(bool terminate)
 {
+    if (QMPlay2Core.renderer() != QMPlay2CoreClass::Renderer::Legacy)
+        QMPlay2Core.gpuInstance()->clearVideoOutput();
     playC.videoSeekPos = -1;
     AVThread::stop(terminate);
 }
@@ -72,7 +115,7 @@ bool VideoThr::hasDecoderError() const
     return decoderError;
 }
 
-QMPlay2PixelFormats VideoThr::getSupportedPixelFormats() const
+AVPixelFormats VideoThr::getSupportedPixelFormats() const
 {
     return videoWriter()->supportedPixelFormats();
 }
@@ -113,11 +156,11 @@ void VideoThr::setFrameSize(int w, int h)
     gotFrameOrError = false;
     ++seq;
 }
-void VideoThr::setARatio(double aRatio, double sar)
+void VideoThr::setARatio(double aRatio, const AVRational &sar)
 {
     updateSubs();
     writer->modParam("AspectRatio", aRatio);
-    lastSampleAspectRatio = sar;
+    lastSAR = sar;
 }
 void VideoThr::setZoom()
 {
@@ -130,81 +173,115 @@ void VideoThr::otherReset()
         writer->modParam("ResetOther", true);
 }
 
-void VideoThr::initFilters(bool processParams)
+void VideoThr::initFilters()
 {
     Settings &QMPSettings = QMPlay2Core.getSettings();
 
-    if (processParams)
-        filtersMutex.lock();
-
+    filtersMutex.lock();
     filters.clear();
 
-    if (!playC.stillImage && QMPSettings.getBool("Deinterlace/ON")) //Deinterlacing filters as first
+    if (!playC.stillImage)
     {
+        const bool deint = QMPSettings.getBool("Deinterlace/ON");
         const bool autoDeint = QMPSettings.getBool("Deinterlace/Auto");
         const bool doubleFramerate = QMPSettings.getBool("Deinterlace/Doubler");
         const bool autoParity = QMPSettings.getBool("Deinterlace/AutoParity");
         const bool topFieldFirst = QMPSettings.getBool("Deinterlace/TFF");
         const quint8 deintFlags = autoDeint | doubleFramerate << 1 | autoParity << 2 | topFieldFirst << 3;
-        bool HWDeint = false, PrepareForHWBobDeint = false;
-        if ((HWDeint = writer->modParam("Deinterlace", 1 | deintFlags << 1)))
-            PrepareForHWBobDeint = doubleFramerate && writer->getParam("PrepareForHWBobDeint").toBool();
-        if (!HWDeint || PrepareForHWBobDeint)
-        {
-            const QString deintFilterName = PrepareForHWBobDeint ? "PrepareForHWBobDeint" : QMPSettings.getString("Deinterlace/SoftwareMethod");
-            if (!deintFilterName.isEmpty())
+
+#ifdef USE_VULKAN
+        auto enableVulkanDeint = [&] {
+            if (!QMPlay2Core.isVulkanRenderer())
+                return false;
+
+            shared_ptr<VideoFilter> deintFilter = make_shared<QmVk::YadifDeint>(
+                static_pointer_cast<QmVk::HWInterop>(getHWDecContext())
+            );
+            if (deintFilter->modParam("DeinterlaceFlags", deintFlags))
             {
-                VideoFilter *deintFilter = filters.on(deintFilterName);
-                bool ok = false;
-                if (deintFilter && deintFilter->modParam("DeinterlaceFlags", deintFlags))
+                deintFilter->modParam("W", W);
+                deintFilter->modParam("H", H);
+                if (deintFilter->processParams())
                 {
-                    deintFilter->modParam("W", W);
-                    deintFilter->modParam("H", H);
-                    ok = deintFilter->processParams();
+                    filters.on(deintFilter);
                 }
-                if (!ok)
+            }
+
+            return true;
+        };
+#endif
+
+        if (getHWDecContext())
+        {
+            if (auto hwFilter = dec->hwAccelFilter())
+            {
+                hwFilter->modParam("Deinterlace", deint);
+                hwFilter->modParam("DeinterlaceFlags", deintFlags);
+                hwFilter->modParam("W", W);
+                hwFilter->modParam("H", H);
+                if (hwFilter->processParams())
+                    filters.on(hwFilter);
+            }
+#ifdef USE_VULKAN
+            else if (deint)
+            {
+                enableVulkanDeint();
+            }
+#endif
+        }
+        else
+        {
+            // Deinterlacing filter as first
+            bool enableSoftwareDeint = deint;
+#ifdef USE_VULKAN
+            if (deint && QMPSettings.getBool("Vulkan/AlwaysGPUDeint"))
+            {
+                if (enableVulkanDeint())
+                    enableSoftwareDeint = false;
+            }
+#endif
+            if (enableSoftwareDeint)
+            {
+                const QString deintFilterName = QMPSettings.getString("Deinterlace/SoftwareMethod");
+                if (auto deintFilter = filters.on(deintFilterName))
                 {
-                    if (deintFilter)
+                    bool ok = false;
+                    if (deintFilter->modParam("DeinterlaceFlags", deintFlags))
+                    {
+                        deintFilter->modParam("W", W);
+                        deintFilter->modParam("H", H);
+                        ok = deintFilter->processParams();
+                    }
+                    if (!ok)
+                    {
                         filters.off(deintFilter);
-                    if (W > 0 && H > 0)
-                        QMPlay2Core.logError(tr("Cannot initialize the deinterlacing filter") + " \"" + deintFilterName + '"', true, true);
+                        if (W > 0 && H > 0)
+                            QMPlay2Core.logError(tr("Cannot initialize the deinterlacing filter") + " \"" + deintFilterName + '"', true, true);
+                    }
                 }
             }
-        }
-    }
-    else
-    {
-        writer->modParam("Deinterlace", 0);
-    }
 
-    if (!playC.stillImage && !hwAccelWriter)
-    {
-        for (QString filterName : QMPSettings.getStringList("VideoFilters"))
-        {
-            if (filterName.leftRef(1).toInt()) //if filter is enabled
+            for (QString filterName : QMPSettings.getStringList("VideoFilters"))
             {
-                VideoFilter *filter = filters.on((filterName = filterName.mid(1)));
-                bool ok = false;
-                if (filter)
+                if (filterName.leftRef(1).toInt()) //if filter is enabled
                 {
-                    filter->modParam("W", W);
-                    filter->modParam("H", H);
-                    if (!(ok = filter->processParams()))
-                        filters.off(filter);
+                    bool ok = false;
+                    filterName = filterName.mid(1);
+                    if (auto filter = filters.on(filterName))
+                    {
+                        filter->modParam("W", W);
+                        filter->modParam("H", H);
+                        if (!(ok = filter->processParams()))
+                            filters.off(filter);
+                    }
+                    if (!ok && W > 0 && H > 0)
+                        QMPlay2Core.logError(tr("Error initializing filter") + " \"" + filterName + '"');
                 }
-                if (!ok && W > 0 && H > 0)
-                    QMPlay2Core.logError(tr("Error initializing filter") + " \"" + filterName + '"');
             }
         }
     }
 
-    if (processParams)
-    {
-        filtersMutex.unlock();
-        if (writer->hasParam("Deinterlace"))
-            writer->processParams();
-    }
-
+    filtersMutex.unlock();
     filters.start();
 }
 
@@ -226,7 +303,7 @@ void VideoThr::updateSubs()
 
 inline VideoWriter *VideoThr::videoWriter() const
 {
-    return (VideoWriter *)writer;
+    return static_cast<VideoWriter *>(writer);
 }
 
 void VideoThr::run()
@@ -234,7 +311,7 @@ void VideoThr::run()
     bool skip = false, paused = false, oneFrame = false, useLastDelay = false, lastOSDListEmpty = true, maybeFlush = false, lastAVDesync = false, interlaced = false, err = false;
     double tmp_time = 0.0, sync_last_pts = 0.0, frame_timer = -1.0, sync_timer = 0.0, framesDisplayedTime = 0.0;
     QMutex emptyBufferMutex;
-    VideoFrame videoFrame;
+    Frame videoFrame;
     unsigned fast = 0;
     int tmp_br = 0, frames = 0, framesDisplayed = 0;
     canWrite = true;
@@ -276,7 +353,7 @@ void VideoThr::run()
 
         if (doScreenshot && !videoFrame.isEmpty())
         {
-            QMetaObject::invokeMethod(this, "screenshot", Q_ARG(VideoFrame, videoFrame));
+            QMetaObject::invokeMethod(this, "screenshot", Q_ARG(Frame, videoFrame));
             doScreenshot = false;
         }
 
@@ -309,11 +386,15 @@ void VideoThr::run()
             continue;
         }
         paused = waiting = false;
+
         Packet packet;
+        double ts = qQNaN();
         if (hasVPackets && mustFetchNewPacket)
+        {
             packet = playC.vPackets.fetch();
-        else
-            packet.ts.setInvalid();
+            if (packet.isTsValid())
+                ts = packet.ts();
+        }
         playC.vPackets.unlock();
         processOneFrame();
         playC.fillBufferB = true;
@@ -352,7 +433,7 @@ void VideoThr::run()
                 if (playC.ass->isASS())
                     playC.ass->addASSEvent(sPacketData);
                 else
-                    playC.ass->addASSEvent(Functions::convertToASS(sPacketData), sPacket.ts, sPacket.duration);
+                    playC.ass->addASSEvent(Functions::convertToASS(sPacketData), sPacket.ts(), sPacket.duration());
             }
             if (!playC.ass->getASS(subtitles, subsPts))
             {
@@ -406,34 +487,35 @@ void VideoThr::run()
 
         if (!packet.isEmpty() || maybeFlush)
         {
-            VideoFrame decoded;
-            QByteArray newPixelFormat;
+            Frame decoded;
+            AVPixelFormat newPixelFormat = AV_PIX_FMT_NONE;
             const int bytes_consumed = dec->decodeVideo(packet, decoded, newPixelFormat, playC.flushVideo, skip ? ~0 : (fast >> 1));
-            if (!newPixelFormat.isEmpty())
+            ts = decoded.isTsValid() ? decoded.ts() : qQNaN();
+            if (newPixelFormat != AV_PIX_FMT_NONE)
                 emit playC.pixelFormatUpdate(newPixelFormat);
             if (playC.flushVideo)
             {
                 useLastDelay = true; //if seeking
                 playC.flushVideo = false;
             }
-            if (playC.videoSeekPos > 0.0 && bytes_consumed <= 0 && !packet.ts.isValid() && decoded.isEmpty())
+            if (playC.videoSeekPos > 0.0 && bytes_consumed <= 0 && !decoded.isTsValid() && decoded.isEmpty())
                 finishAccurateSeek();
             if (!decoded.isEmpty())
             {
-                if (decoded.size.width != W || decoded.size.height != H)
+                if (decoded.width() != W || decoded.height() != H)
                 {
                     //Frame size has been changed
                     filtersMutex.unlock();
                     updateMutex.lock();
                     mutex.unlock();
-                    emit playC.frameSizeUpdate(decoded.size.width, decoded.size.height);
+                    emit playC.frameSizeUpdate(decoded.width(), decoded.height());
                     updateMutex.lock(); //Wait for "frameSizeUpdate()" to be finished
                     mutex.lock();
                     updateMutex.unlock();
                     filtersMutex.lock();
                 }
-                interlaced = decoded.interlaced;
-                filters.addFrame(decoded, packet.ts);
+                interlaced = decoded.isInterlaced();
+                filters.addFrame(decoded);
                 gotFrameOrError = true;
             }
             else if (skip)
@@ -450,23 +532,33 @@ void VideoThr::run()
         }
 
         // This thread will wait for "DemuxerThr" which'll detect this error and restart with new decoder.
-        decoderError = (dec->hasCriticalError() || videoWriter()->hwAccelError());
+        if (dec->hasCriticalError())
+        {
+            decoderError = true;
+        }
+        else if (auto hwDecContext = getHWDecContext())
+        {
+            decoderError = hwDecContext->hasError();
+        }
 
-        const bool ptsIsValid = filters.getFrame(videoFrame, packet.ts);
+        const bool ptsIsValid = filters.getFrame(videoFrame);
+        if (ptsIsValid)
+            ts = videoFrame.ts();
         filtersMutex.unlock();
 
-        if ((maybeFlush = packet.ts.isValid()))
+        if ((maybeFlush = !qIsNaN(ts)))
         {
-            if (packet.sampleAspectRatio && lastSampleAspectRatio != -1.0 && !qFuzzyCompare(lastSampleAspectRatio, packet.sampleAspectRatio)) //Aspect ratio has been changed
+            const AVRational currSAR = videoFrame.sampleAspectRatio();
+            if (currSAR.num != 0 && currSAR.den != 0 && lastSAR.num != 0 && lastSAR.den != 0 && av_cmp_q(lastSAR, currSAR) != 0) //Aspect ratio has been changed
             {
-                lastSampleAspectRatio = -1.0; //Needs to be updated later
-                emit playC.aRatioUpdate(packet.sampleAspectRatio); //Sets "lastSampleAspectRatio", because it calls "setARatio()";
+                lastSAR = {0, 0}; //Needs to be updated later
+                emit playC.aRatioUpdate(currSAR); //Sets "lastSAR", because it calls "setARatio()";
             }
 
             if (playC.videoSeekPos > 0.0)
             {
                 bool cont = true;
-                if (packet.ts >= playC.videoSeekPos)
+                if (ts >= playC.videoSeekPos)
                 {
                     finishAccurateSeek();
                     if (processOneFrame())
@@ -481,10 +573,10 @@ void VideoThr::run()
                 }
             }
 
-            if (ptsIsValid || packet.ts > playC.pos)
-                playC.chPos(packet.ts);
+            if (ptsIsValid || ts > playC.pos)
+                playC.chPos(ts);
 
-            double delay = packet.ts - playC.frame_last_pts;
+            double delay = ts - playC.frame_last_pts;
             if (useLastDelay || delay <= 0.0 || (playC.frame_last_pts <= 0.0 && delay > playC.frame_last_delay))
             {
                 delay = playC.frame_last_delay;
@@ -497,7 +589,7 @@ void VideoThr::run()
             delay /= playC.speed;
 
             playC.frame_last_delay = delay;
-            playC.frame_last_pts = packet.ts;
+            playC.frame_last_pts = ts;
 
             if (playC.skipAudioFrame < 0.0)
                 playC.skipAudioFrame = 0.0;
@@ -525,7 +617,7 @@ void VideoThr::run()
                     sync_timer = gettime();
                 }
 
-                const double diff = packet.ts - (delay + sync_pts - playC.videoSync);
+                const double diff = ts - (delay + sync_pts - playC.videoSync);
                 const double sync_threshold = qMax(delay, playC.audio_last_delay);
                 const double max_threshold = qMax(sync_threshold * 2.0, 0.15);
                 const double fDiff = qAbs(diff);
@@ -615,7 +707,7 @@ void VideoThr::run()
                 if (!skip && canWrite)
                 {
                     oneFrame = canWrite = false;
-                    QMetaObject::invokeMethod(this, "write", Q_ARG(VideoFrame, videoFrame), Q_ARG(quint32, seq));
+                    QMetaObject::invokeMethod(this, "write", Q_ARG(Frame, videoFrame), Q_ARG(quint32, seq));
                     if (canSkipFrames)
                         ++framesDisplayed;
                 }
@@ -630,43 +722,64 @@ void VideoThr::run()
     }
 }
 
-void VideoThr::write(VideoFrame videoFrame, quint32 lastSeq)
+void VideoThr::write(Frame videoFrame, quint32 lastSeq)
 {
     canWrite = true;
-    if (lastSeq == seq && writer->readyWrite() && !videoWriter()->hwAccelError())
-    {
-        QMPlay2GUI.screenSaver->inhibit(0);
-        videoWriter()->writeVideo(videoFrame);
-    }
+
+    if (lastSeq != seq || !writer->readyWrite())
+        return;
+
+    auto hwDecContext = getHWDecContext();
+    if (hwDecContext && hwDecContext->hasError())
+        return;
+
+    QMPlay2GUI.screenSaver->inhibit(0);
+    videoWriter()->writeVideo(videoFrame);
 }
-void VideoThr::screenshot(VideoFrame videoFrame)
+void VideoThr::screenshot(Frame videoFrame)
 {
     ImgScaler imgScaler;
-    const int aligned8W = Functions::aligned(W, 8);
-    if (imgScaler.create(videoFrame, aligned8W, H, (bool)hwAccelWriter))
+    QImage img;
+
+#ifdef USE_OPENGL
+    if (auto hwGLInterop = dynamic_pointer_cast<OpenGLHWInterop>(getHWDecContext()))
     {
-        QImage img(aligned8W, H, QImage::Format_RGB32);
-        bool ok = true;
-        if (!hwAccelWriter)
-            imgScaler.scale(videoFrame, img.bits());
-        else
-            ok = videoWriter()->hwAccelGetImg(videoFrame, img.bits(), &imgScaler);
-        if (!ok)
-            QMPlay2Core.logError(tr("Cannot create screenshot"));
-        else
-        {
-            const QString ext = QMPlay2Core.getSettings().getString("screenshotFormat");
-            const QString dir = QMPlay2Core.getSettings().getString("screenshotPth");
-            quint16 num = 0;
-            for (const QString &f : QDir(dir).entryList({"QMPlay2_snap_?????" + ext}, QDir::Files, QDir::Name))
-            {
-                const quint16 n = f.midRef(13, 5).toUShort();
-                if (n > num)
-                    num = n;
-            }
-            img.save(dir + "/QMPlay2_snap_" + QString("%1").arg(++num, 5, 10, QChar('0')) + ext);
-        }
+        img = hwGLInterop->getImage(videoFrame);
     }
+    else
+#endif
+    if (imgScaler.create(videoFrame, W, H))
+    {
+#ifdef USE_VULKAN
+        if (auto vkHwInterop = dynamic_pointer_cast<QmVk::HWInterop>(getHWDecContext()))
+        {
+            vkHwInterop->map(videoFrame);
+            vkHwInterop->sync({videoFrame});
+            if (vkHwInterop->hasError())
+                videoFrame.clear();
+        }
+#endif
+        img = QImage(W, H, QImage::Format_RGB32);
+        if (!imgScaler.scale(videoFrame, img.bits()))
+            img = QImage();
+    }
+
+    if (img.isNull())
+    {
+        QMPlay2Core.logError(tr("Cannot create screenshot"));
+        return;
+    }
+
+    const QString ext = QMPlay2Core.getSettings().getString("screenshotFormat");
+    const QString dir = QMPlay2Core.getSettings().getString("screenshotPth");
+    quint16 num = 0;
+    for (const QString &f : QDir(dir).entryList({"QMPlay2_snap_?????" + ext}, QDir::Files, QDir::Name))
+    {
+        const quint16 n = f.midRef(13, 5).toUShort();
+        if (n > num)
+            num = n;
+    }
+    img.save(dir + "/QMPlay2_snap_" + QString("%1").arg(++num, 5, 10, QChar('0')) + ext);
 }
 void VideoThr::pause()
 {
