@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -32,7 +32,7 @@ public:
 private:
     bool setAudioParameters(uchar, uint srate) override;
     void clearBuffers() override;
-    double filter(Buffer &data, bool flush) override;
+    double filter(QByteArray &data, bool flush) override;
 
     void alloc();
 
