@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -28,7 +28,7 @@ public:
     bool set() override;
 private:
     bool setAudioParameters(uchar, uint) override;
-    double filter(Buffer &, bool) override;
+    double filter(QByteArray &, bool) override;
 
     bool enabled, hasParameters, canFilter;
     uchar chn;
