@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -528,6 +528,11 @@ void DownloaderThread::listSlot(int param, qint64 val, const QString &filePath)
             downloadLW->resize(downloadLW->size() + QSize(0, 1));
             downloadLW->resize(downloadLW->size() - QSize(0, 1));
 
+            if (!downloadLW->currentItem())
+                downloadLW->setCurrentItem(item);
+            else
+                downloadLW->scrollToItem(item, QAbstractItemView::EnsureVisible);
+
             break;
         case NAME:
             downloadItemW->setName(name);
@@ -672,7 +677,7 @@ void DownloaderThread::run()
 
                         if (length > 0.0)
                         {
-                            pos = qMax<double>(pos, packet.ts);
+                            pos = qMax<double>(pos, packet.ts());
                             emit listSig(SET_POS, pos * 100 / length);
                         }
                     }
@@ -1156,7 +1161,6 @@ void Downloader::download()
         action->property("param").toString(),
         action->property("preset").toString()
     );
-    downloadLW->setCurrentItem(downloadLW->invisibleRootItem()->child(0));
 }
 void Downloader::itemDoubleClicked(QTreeWidgetItem *item)
 {
