@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -18,13 +18,12 @@
 
 #pragma once
 
-#define QMPLAY2_NOPTS_VALUE ((qint64)AV_NOPTS_VALUE)
-
 #define DecoderName "FFmpeg Decoder"
 #define DecoderVAAPIName "FFmpeg VA-API Decoder"
 #define DecoderVDPAUName "FFmpeg VDPAU Decoder"
 #define DecoderVDPAU_NWName DecoderVDPAUName " (no output)"
 #define DecoderDXVA2Name "FFmpeg DXVA2 Decoder"
+#define DecoderD3D11VAName "FFmpeg D3D11VA Decoder"
 #define DecoderVTBName "FFmpeg VideoToolbox Decoder"
 #define DemuxerName "FFmpeg"
 #define VAAPIWriterName "VA-API"
