@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -26,17 +26,16 @@ protected:
     FFDecHWAccel();
     ~FFDecHWAccel();
 
-    VideoWriter *HWAccel() const override final;
-
     bool hasHWAccel(const char *hwaccelName) const;
 
-    int decodeVideo(Packet &encodedPacket, VideoFrame &decoded, QByteArray &newPixFmt, bool flush, unsigned hurryUp) override;
-    virtual void downloadVideoFrame(VideoFrame &decoded);
+    bool hasHWDecContext() const override final;
+
+    int decodeVideo(const Packet &encodedPacket, Frame &decoded, AVPixelFormat &newPixFmt, bool flush, unsigned hurryUp) override;
+    virtual void downloadVideoFrame(Frame &decoded);
 
     bool hasCriticalError() const override;
 
-    /**/
-
-    VideoWriter *m_hwAccelWriter;
-    bool m_hasCriticalError;
+protected:
+    bool m_hasCriticalError = false;
+    bool m_hasHWDecContext = false;
 };
