@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -21,7 +21,7 @@
 #include <OpenThr.hpp>
 
 #include <ChapterProgramInfo.hpp>
-#include <TimeStamp.hpp>
+#include <StreamInfo.hpp>
 
 #include <QCoreApplication>
 
@@ -35,7 +35,7 @@ struct AVDictionary;
 struct AVStream;
 struct AVPacket;
 class OggHelper;
-struct Packet;
+class Packet;
 
 class FormatContext
 {
@@ -70,7 +70,7 @@ public:
     void setStreamOffset(double offset);
 
     bool isLocal, isStreamed, isError;
-    StreamsInfo streamsInfo;
+    QList<StreamInfo *> streamsInfo;
     double currPos;
 private:
     StreamInfo *getStreamInfo(AVStream *stream) const;
@@ -80,7 +80,7 @@ private:
 
     QVector<int> index_map;
     QVector<AVStream *> streams;
-    QVector<TimeStamp> streamsTS;
+    QVector<double> streamsTS;
     QVector<double> streamsOffset;
     QVector<double> nextDts;
     AVFormatContext *formatCtx;
