@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -26,9 +26,9 @@
 #include <va/va_vpp.h>
 
 struct AVBufferRef;
-class VideoFrame;
-class ImgScaler;
 struct AVFrame;
+class QImage;
+class Frame;
 
 class VAAPI
 {
@@ -38,7 +38,7 @@ public:
     VAAPI();
     ~VAAPI();
 
-    bool open(bool openGL);
+    bool open(bool checkNV12);
 
     void init(int width, int height, bool allowFilters);
 
@@ -49,10 +49,10 @@ public:
 
     void applyVideoAdjustment(int brightness, int contrast, int saturation, int hue);
 
-    bool filterVideo(const VideoFrame &frame, VASurfaceID &id, int &field);
+    bool filterVideo(const Frame &frame, VASurfaceID &id, int &field);
 
     quint8 *getNV12Image(VAImage &image, VASurfaceID surfaceID) const;
-    bool getImage(const VideoFrame &videoFrame, void *dest, ImgScaler *nv12ToRGB32) const;
+    QImage getImage(const Frame &videoFrame) const;
 
     void insertFrame(VASurfaceID id, AVFrame *frame);
 
@@ -64,6 +64,8 @@ private:
 public:
     AVBufferRef *m_hwDeviceBufferRef = nullptr;
 
+    QString m_vendor;
+
     bool ok = false;
 
     int m_fd = -1;
@@ -91,5 +93,5 @@ private:
     int m_nBackwardRefs, m_nForwardRefs;
     bool m_hasVppFrame = false;
 
-    QHash<VASurfaceID, VideoFrame> m_vppFrames;
+    QHash<VASurfaceID, Frame> m_vppFrames;
 };
