@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -20,6 +20,7 @@
 #include <Functions.hpp>
 
 #include <QPainter>
+#include <QPainterPath>
 
 #include <cmath>
 
@@ -183,10 +184,9 @@ void SimpleVis::soundBuffer(const bool enable)
 
 bool SimpleVis::set()
 {
-#ifdef USE_OPENGL
-    w.setUseOpenGL(sets().getBool("UseOpenGL"));
-#endif
-    w.interval = sets().getInt("RefreshTime");
+    const bool isGlOnWindow = QMPlay2Core.isGlOnWindow();
+    w.setUseOpenGL(isGlOnWindow);
+    w.interval = isGlOnWindow ? 1 : sets().getInt("RefreshTime");
     sndLen = sets().getInt("SimpleVis/SoundLength") / 1000.0f;
     if (w.tim.isActive())
         w.start();
