@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -21,7 +21,9 @@
 #include <QWidget>
 #include <QTimer>
 
-#include <QOpenGLWidget>
+#ifdef USE_OPENGL
+#   include <QOpenGLWidget>
+#endif
 
 class DockWidget;
 
@@ -56,8 +58,10 @@ private:
 
     bool eventFilter(QObject *watched, QEvent *event) override final;
 
-    QOpenGLWidget *glW;
+#ifdef USE_OPENGL
+    QOpenGLWidget *glW = nullptr;
     bool m_pendingUpdate = false;
+#endif
     const bool m_isWL;
     bool dockWidgetVisible = false;
 private slots:
