@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -46,9 +46,6 @@ public:
 private:
     void saveSettings() override;
 
-#ifdef USE_OPENGL
-    QCheckBox *useOpenGLB;
-#endif
-    QSpinBox *refTimeB, *sndLenB, *fftSizeB;
+    QSpinBox *refTimeB = nullptr, *sndLenB, *fftSizeB;
     QCheckBox *m_fftLinearScaleB;
 };
