@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -74,7 +74,7 @@ public:
         m_aborted(false),
         m_afterOpen(false)
     {}
-    ~NetworkReplyPriv() final = default;
+    ~NetworkReplyPriv() = default;
 
     NetworkReply *m_networkReply;
 
@@ -112,7 +112,7 @@ private:
         else
         {
             AVDictionary *options = nullptr;
-            const QByteArray url = Functions::prepareFFmpegUrl(m_url, options, m_rawHeaders.isEmpty(), m_rawHeaders.isEmpty(), false, m_customUserAgent).toUtf8();
+            const QByteArray url = Functions::prepareFFmpegUrl(m_url, options, true, m_rawHeaders.isEmpty(), m_rawHeaders.isEmpty(), false, m_customUserAgent).toUtf8();
             av_dict_set(&options, "seekable", "0", 0);
             if (!m_postData.isNull())
             {
