@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -18,22 +18,31 @@
 
 #include <QMPlay2OSD.hpp>
 
-#include <QAtomicInteger>
-static QAtomicInteger<quint64> g_id;
+#if USE_VULKAN
+#   include <vulkan/VulkanBufferPool.hpp>
+#endif
 
-void QMPlay2OSD::genId()
+#include <atomic>
+
+using namespace std;
+
+static atomic<uint64_t> g_id;
+
+QMPlay2OSD::QMPlay2OSD()
 {
-    m_id = ++g_id;
+    clear();
+}
+QMPlay2OSD::~QMPlay2OSD()
+{
+    clear();
 }
 
-void QMPlay2OSD::clear(bool all)
+double QMPlay2OSD::leftDuration()
 {
-    m_images.clear();
-    m_text.clear();
-    if (all)
-        m_pts = m_duration = -1.0;
-    m_needsRescale = m_started = false;
-    m_id = 0;
+    if (!m_started || m_pts != -1.0)
+        return 0.0;
+
+    return m_duration - m_timer.elapsed() / 1000.0;
 }
 
 void QMPlay2OSD::start()
@@ -42,9 +51,45 @@ void QMPlay2OSD::start()
     if (m_pts == -1.0)
         m_timer.start();
 }
-double QMPlay2OSD::leftDuration()
+
+void QMPlay2OSD::iterate(const IterateCallback &fn) const
 {
-    if (!m_started || m_pts != -1.0)
-        return 0.0;
-    return m_duration - m_timer.elapsed() / 1000.0;
+    for (auto &&image : m_images)
+        fn(image);
 }
+
+void QMPlay2OSD::genId()
+{
+    m_id = ++g_id;
+}
+
+void QMPlay2OSD::clear()
+{
+    m_images.clear();
+    m_text.clear();
+    m_duration = m_pts = -1.0;
+    m_needsRescale = m_started = false;
+    m_timer.invalidate();
+    m_id = 0;
+#ifdef USE_VULKAN
+    if (m_returnVkBufferFn)
+    {
+        m_returnVkBufferFn();
+        m_returnVkBufferFn = nullptr;
+    }
+#endif
+}
+
+#ifdef USE_VULKAN
+void QMPlay2OSD::setReturnVkBufferFn(
+    const std::weak_ptr<QmVk::BufferPool> &bufferPoolWeak,
+    std::shared_ptr<QmVk::Buffer> &&buffer)
+{
+    m_returnVkBufferFn = [=]() mutable {
+        if (auto vkBufferPool = bufferPoolWeak.lock())
+            vkBufferPool->put(move(buffer));
+        else
+            buffer.reset();
+    };
+}
+#endif
