@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2019  Błażej Szczygieł
+    Copyright (C) 2010-2020  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -18,33 +18,20 @@
 
 #include <SndResampler.hpp>
 
-#include <Buffer.hpp>
-
 #include <QByteArray>
 
 #include <cmath>
 
 extern "C"
 {
-#ifdef QMPLAY2_AVRESAMPLE
-    #include <libavresample/avresample.h>
-    #include <libavutil/samplefmt.h>
-    #define set_matrix avresample_set_matrix
-#else
     #include <libswresample/swresample.h>
     #include <libavutil/channel_layout.h>
-    #define set_matrix swr_set_matrix
-#endif
     #include <libavutil/opt.h>
 }
 
 const char *SndResampler::name() const
 {
-#ifdef QMPLAY2_AVRESAMPLE
-    return "AVResample";
-#else
     return "SWResample";
-#endif
 }
 
 bool SndResampler::create(int _src_samplerate, int _src_channels, int _dst_samplerate, int _dst_channels)
@@ -60,19 +47,10 @@ bool SndResampler::create(int _src_samplerate, int _src_channels, int _dst_sampl
     if (!src_samplerate || !dst_samplerate || !src_chn_layout || !dst_chn_layout)
         return false;
 
-#ifdef QMPLAY2_AVRESAMPLE
-    snd_convert_ctx = avresample_alloc_context();
-    av_opt_set_int(snd_convert_ctx, "in_channel_layout",  src_chn_layout,    0);
-    av_opt_set_int(snd_convert_ctx, "out_channel_layout", dst_chn_layout,    0);
-    av_opt_set_int(snd_convert_ctx, "in_sample_rate",     src_samplerate,    0);
-    av_opt_set_int(snd_convert_ctx, "out_sample_rate",    dst_samplerate,    0);
-    av_opt_set_int(snd_convert_ctx, "in_sample_fmt",      AV_SAMPLE_FMT_FLT, 0);
-    av_opt_set_int(snd_convert_ctx, "out_sample_fmt",     AV_SAMPLE_FMT_FLT, 0);
-#else
     if (!(snd_convert_ctx = swr_alloc_set_opts(nullptr, dst_chn_layout, AV_SAMPLE_FMT_FLT, dst_samplerate, src_chn_layout, AV_SAMPLE_FMT_FLT, src_samplerate, 0, nullptr)))
         return false;
-#endif
-    av_opt_set_int(snd_convert_ctx, "linear_interp",      true,              0);
+
+    av_opt_set_int(snd_convert_ctx, "linear_interp", true, 0);
     if (dst_channels > src_channels)
     {
         double matrix[dst_channels][src_channels];
@@ -82,13 +60,10 @@ bool SndResampler::create(int _src_samplerate, int _src_channels, int _dst_sampl
             matrix[i][c] = 1.0;
             c = (c + 1) % src_channels;
         }
-        set_matrix(snd_convert_ctx, (const double *)matrix, src_channels);
+        swr_set_matrix(snd_convert_ctx, (const double *)matrix, src_channels);
     }
-#ifdef QMPLAY2_AVRESAMPLE
-    if (avresample_open(snd_convert_ctx))
-#else
+
     if (swr_init(snd_convert_ctx))
-#endif
     {
         destroy();
         return false;
@@ -96,40 +71,22 @@ bool SndResampler::create(int _src_samplerate, int _src_channels, int _dst_sampl
     return true;
 }
 void SndResampler::convert(const QByteArray &src, QByteArray &dst)
-{
-    convertInternal(src, dst);
-}
-void SndResampler::convert(const Buffer &src, Buffer &dst)
-{
-    convertInternal(src, dst);
-}
-void SndResampler::destroy()
-{
-#ifdef QMPLAY2_AVRESAMPLE
-    avresample_free(&snd_convert_ctx);
-#else
-    swr_free(&snd_convert_ctx);
-#endif
-}
-
-template<typename T>
-void SndResampler::convertInternal(const T &src, T &dst)
 {
     const int in_size = src.size() / src_channels / sizeof(float);
-    const int out_size = ceil(in_size * (double)dst_samplerate / (double)src_samplerate);
+    const int out_size = std::ceil(in_size * (double)dst_samplerate / (double)src_samplerate);
 
     dst.reserve(out_size * sizeof(float) * dst_channels);
 
     const quint8 *in[] = {(const quint8 *)src.constData()};
     quint8 *out[] = {(quint8 *)dst.data()};
 
-#ifdef QMPLAY2_AVRESAMPLE
-    const int converted = avresample_convert(snd_convert_ctx, out, 1, out_size, (quint8 *const *)in, 1, in_size);
-#else
     const int converted = swr_convert(snd_convert_ctx, out, out_size, in, in_size);
-#endif
     if (converted > 0)
         dst.resize(converted * sizeof(float) * dst_channels);
     else
         dst.clear();
 }
+void SndResampler::destroy()
+{
+    swr_free(&snd_convert_ctx);
+}
