@@ -49,10 +49,14 @@ vk::Format Instance::fromFFmpegPixelFormat(int avPixFmt)
     {
         case AV_PIX_FMT_GRAY8:
             return vk::Format::eR8Unorm;
+#if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(55, 78, 100)
         case AV_PIX_FMT_GRAY9:
+#endif
         case AV_PIX_FMT_GRAY10:
         case AV_PIX_FMT_GRAY12:
+#if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(56, 22, 100)
         case AV_PIX_FMT_GRAY14:
+#endif
         case AV_PIX_FMT_GRAY16:
             return vk::Format::eR16Unorm;
 
@@ -245,10 +249,14 @@ AVPixelFormats Instance::supportedPixelFormats() const
     if (checkImageFormat(vk::Format::eR16Unorm) && checkImageFormat(vk::Format::eR16G16Unorm))
     {
         pixelFormats += {
+#if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(55, 78, 100)
             AV_PIX_FMT_GRAY9,
+#endif
             AV_PIX_FMT_GRAY10,
             AV_PIX_FMT_GRAY12,
+#if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(56, 22, 100)
             AV_PIX_FMT_GRAY14,
+#endif
             AV_PIX_FMT_GRAY16,
 
             AV_PIX_FMT_P010,
@@ -410,6 +418,8 @@ void Instance::sortPhysicalDevices(vector<shared_ptr<PhysicalDevice>> &physicalD
 
         break;
     }
+#else
+    Q_UNUSED(physicalDevices)
 #endif
 }
 
